"""
Created on 26 mars 2018

@author: Tonneau Stephane
"""

import os

AIRFLOW_PROCESS = "airflow"
UNKNOWN_PROCESS = "Unknown"

class EnvironmentFactory():
    """Class that can be used to manage environment specificities"""

    def __init__(self, **configuration):
        """Initialisator of the class

        :param configuration: specific parameters of the environment
        :type configuration: a dictionary
        """
        self.system_env = None
        self.environment = None
        if 'SPARK_YARN_MODE' in os.environ:
            import pidclient.environment.spark_cluster as spark_cluster
            self.system_env = "spark"
            self.environment = spark_cluster.SparkEnvironment(**configuration)
        elif ('SPARK_ENV_LOADED' in os.environ) or ('_SPARK_ASSEMBLY' in os.environ):
            import pidclient.environment.spark_local as spark_local
            self.system_env = "local"
            self.environment = spark_local.LocalEnvironment(**configuration)
        else:
            this_env = None
            try:
                import psutil
                process = psutil.Process()
                while (this_env is None) and (process is not None):
                    if AIRFLOW_PROCESS in str(process):
                        this_env = AIRFLOW_PROCESS
                    else:
                        process = process.parent()
            except:
                this_env = UNKNOWN_PROCESS
            if this_env == AIRFLOW_PROCESS:
                import pidclient.environment.airflow_env as airflow_env
                self.system_env = AIRFLOW_PROCESS
                self.environment = airflow_env.AirflowEnvironment(**configuration)
            else:
                import pidclient.base_utils as base_utils
                self.system_env = UNKNOWN_PROCESS
                self.environment = base_utils.SystemEnvironment(**configuration)
                try:
                    import psutil
                    process = psutil.Process()
                    self.environment.job_id = str(process.pid) + "." + str(process.create_time())
                    self.environment.main_id = str(os.getpid()) + "_" + str(process.create_time()).replace(".", "_")
                except ImportError:
                    import time
                    import random
                    the_time = int(time.time())
                    sliced_time = int((the_time + 36000)/ 72000)
                    self.environment.job_id = str(os.getpid()) + "." + self.environment.host + "." + str(sliced_time)
                    self.environment.main_id = str(os.getpid()) + "_" + self.environment.host.replace(".", "_") + "_" + str(the_time)+ "_" + str(int(random.uniform(0, 999999999999999)))
